<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="649"/>
        <source>Activate task %1</source>
        <translation>Aktiviraj zadatak %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="546"/>
        <source>Application</source>
        <translation>Program</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="580"/>
        <source>To &amp;Desktop</source>
        <translation>Na &amp;radnu površinu</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="583"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Sve radne površine</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="593"/>
        <source>Desktop &amp;%1</source>
        <translation>Radna površina &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="603"/>
        <source>&amp;To Current Desktop</source>
        <translation>Na &amp;trenutačnu radnu površinu</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="612"/>
        <source>Move To N&amp;ext Monitor</source>
        <translation>Prijeđi na slj&amp;edeći monitor</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="618"/>
        <source>Move To &amp;Previous Monitor</source>
        <translation>Prijeđi na &amp;prethodni monitor</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="624"/>
        <source>&amp;Move</source>
        <translation>&amp;Prijeđi</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="629"/>
        <source>Resi&amp;ze</source>
        <translation>Promijeni &amp;veličinu</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="638"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ksimiraj</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="647"/>
        <source>Maximize vertically</source>
        <translation>Maksimiraj okomito</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="654"/>
        <source>Maximize horizontally</source>
        <translation>Maksimiraj vodoravno</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="662"/>
        <source>&amp;Restore</source>
        <translation>&amp;Obnovi</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="670"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimiraj</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="678"/>
        <source>Roll down</source>
        <translation>Rasklopi naslovnu traku</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="686"/>
        <source>Roll up</source>
        <translation>Sklopi u naslovnu traku</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="695"/>
        <source>&amp;Layer</source>
        <translation>S&amp;loj</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="700"/>
        <source>Always on &amp;top</source>
        <translation>Uvijek izna&amp;d</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="705"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normalno</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="710"/>
        <source>Always on &amp;bottom</source>
        <translation>Uvijek i&amp;spod</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="717"/>
        <source>&amp;Close</source>
        <translation>&amp;Zatvori</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="84"/>
        <source>Group</source>
        <translation>Grupa</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="86"/>
        <source>Close group</source>
        <translation>Zatvori grupu</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Upravljač zadataka – Postavke</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Opće</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Prikaži samo prozore s radne površine</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Prikaži samo prozore s ekrana ploče</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Prikaži samo smanjene prozore</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Nadigni smanjene prozore na trenutačnoj radnoj površini</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Zatvori pritiskom srednje gumba</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="254"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="264"/>
        <source>Comma separated list of window classes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="257"/>
        <source>Exclude from taskbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Prelazi po prozorima okretanjem kotačića miša</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>&amp;Grupiranje prozora</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Prikaži skočni prozor prilikom prelaska mišem</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="169"/>
        <source>Appearance</source>
        <translation>Izgled</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="178"/>
        <source>Button style</source>
        <translation>Stil gumba</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="188"/>
        <source>Maximum button width</source>
        <translation>Maksimalna širina gumba</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="201"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="227"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation>Kotačić miša</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation>Prag razlike kotačića</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Put buttons of the same class next to each other</source>
        <translation>Stavi gumbe iste klase jedan pored drugog</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="214"/>
        <source>Maximum button height</source>
        <translation>Maksimalna visina gumba</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Automatski ok&amp;reni gumbe kad ploča stoji okomito</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="247"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Koristi ikone na osnovi WindowClass, ako je dostupno</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Icon and text</source>
        <translation>Ikona i tekst</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only icon</source>
        <translation>Samo ikone</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Only text</source>
        <translation>Samo tekst</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Disabled</source>
        <translation>Deaktivirano</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation>Kliži gore za nadizanje, dolje za smanjivanje</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation>Kliži gore za smanjivanje, dolje za nadizanje</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="54"/>
        <source>Scroll up to move to next desktop, down to previous</source>
        <translation>Kliži gore za prelaženje na sljedeću radnu površinu, dolje na prethodnu</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
        <source>Scroll up to move to previous desktop, down to next</source>
        <translation>Kliži gore za prelaženje na prethodnu radnu površinu, dolje na sljedeću</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="60"/>
        <source>Current</source>
        <translation>Trenutačna</translation>
    </message>
</context>
</TS>
